@@ -2,4 +2,7 @@
 from configPy.jsonConfigParser import JSONConfigParser
 
 # TXTConfigParser - TXT config Parser Object
-from configPy.txtConfigParser import TXTConfigParser
\ No newline at end of file
+from configPy.txtConfigParser import TXTConfigParser
+
+# NDJSONConfigParser - Newline Delimited JSON config Parser Object
+from configPy.ndjsonConfigParser import NDJSONConfigParser
\ No newline at end of file
